==> airbridge_flutter_sdk-1.0.0.tar.gz: example/ios/Runner/AppDelegate.m <==
#include "AppDelegate.h"
#include "GeneratedPluginRegistrant.h"

#import <AirbridgeFL.h>

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    [AirbridgeFL setSessionTimeout:15000];
    [AirbridgeFL getInstance:@"67b4ad7fa85d46499cb2c4ad952a87ef"
                     appName:@"abrfl"
           withLaunchOptions:launchOptions];
    
    [GeneratedPluginRegistrant registerWithRegistry:self];
    return [super application:application didFinishLaunchingWithOptions:launchOptions];
}

- (BOOL)application:(UIApplication *)app
            openURL:(NSURL *)url
            options:(NSDictionary<UIApplicationOpenURLOptionsKey,id> *)options
{
    [AirbridgeFL.deeplink handleURLSchemeDeeplink:url
                                 withSourceBundle:options[UIApplicationOpenURLOptionsSourceApplicationKey]];
    
    return YES;
}

- (BOOL)application:(UIApplication *)application
            openURL:(NSURL *)url
  sourceApplication:(NSString *)sourceApplication
         annotation:(id)annotation
{
    [AirbridgeFL.deeplink handleURLSchemeDeeplink:url
                                 withSourceBundle:sourceApplication];
    
    return YES;
}

 - (BOOL)application:(UIApplication *)application
continueUserActivity:(NSUserActivity *)userActivity
  restorationHandler:(void (^)(NSArray<id<UIUserActivityRestoring>> * _Nullable))restorationHandler
{
    [AirbridgeFL.deeplink handleUniversalLink:userActivity.webpageURL];
    
    return YES;
}

@end

==> airbridge_flutter_sdk-1.3.3.tar.gz: example/ios/Runner/AppDelegate.m <==
#include "AppDelegate.h"
#include "GeneratedPluginRegistrant.h"

#import <AirbridgeFL.h>

#import <AppTrackingTransparency/AppTrackingTransparency.h>

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    [AirbridgeFL getInstance:@"67b4ad7fa85d46499cb2c4ad952a87ef"
                     appName:@"abrfl"
           withLaunchOptions:launchOptions];
    
    if (@available(iOS 14, *)) {
        [ATTrackingManager requestTrackingAuthorizationWithCompletionHandler:^(ATTrackingManagerAuthorizationStatus status) {}];
    }
    
    [GeneratedPluginRegistrant registerWithRegistry:self];
    return [super application:application didFinishLaunchingWithOptions:launchOptions];
}

- (BOOL)application:(UIApplication *)app
            openURL:(NSURL *)url
            options:(NSDictionary<UIApplicationOpenURLOptionsKey,id> *)options
{
    [AirbridgeFL.deeplink handleURLSchemeDeeplink:url];
    
    return YES;
}

- (BOOL)application:(UIApplication *)application
            openURL:(NSURL *)url
  sourceApplication:(NSString *)sourceApplication
         annotation:(id)annotation
{
    [AirbridgeFL.deeplink handleURLSchemeDeeplink:url];
    
    return YES;
}

 - (BOOL)application:(UIApplication *)application
continueUserActivity:(NSUserActivity *)userActivity
  restorationHandler:(void (^)(NSArray<id<UIUserActivityRestoring>> * _Nullable))restorationHandler
{
    [AirbridgeFL.deeplink handleUniversalLink:userActivity.webpageURL];
    
    return YES;
}

@end
